@@ -86,12 +86,6 @@ AAptInterface::AAptInterface(QObject* parent = 0) : QObject(parent)
 	QFile logfile(KLogFile);
 	logfile.remove();
 
-	// clear files left from old versions
-	QFile f1("/root/.fapman/dates.cache");
-	f1.remove();
-	QFile f2("/root/.fapman/lastupdate");
-	f2.remove();
-
 	readRepositoryInfo();
 }
 
@@ -106,7 +100,32 @@ AAptInterface::~AAptInterface()
 	if( iProcAptGetClean->state() != QProcess::NotRunning )
 		iProcAptGetClean->kill();
 
-	delete iDataReadBuffer;
+	// qprocesses are automatically deleted by their parent
+
+	QHashIterator<QString, Package*> a( iPackagesAvailable );
+	while (a.hasNext())
+	{
+		a.next();
+		delete a.value();
+	}
+	iPackagesAvailable.clear();
+
+	QHashIterator<QString, Package*> i( iPackagesInstalled );
+	while (i.hasNext())
+	{
+		i.next();
+		delete i.value();
+	}
+	iPackagesInstalled.clear();
+
+	for(int x=0; x<iRepositories.count(); x++) {
+		if( iRepositories.at(x) )
+			delete iRepositories.at(x);
+	}
+	iRepositories.clear();
+
+	delete[] iDataReadBuffer;
+	iDataReadBuffer=0;
 }
 
 void AAptInterface::addQueuedOperation(interfaceMode mode_)
@@ -218,7 +237,7 @@ void AAptInterface::cleanAfterError()
 	iProcessPackageVersions.clear();
 }
 
-bool AAptInterface::running()
+bool AAptInterface::running() const
 {
 	if( iMode == ModeNone )
 		return false;
@@ -526,7 +545,7 @@ QString AAptInterface::finishProcessCommonErrorMessages(QByteArray& output)
 	} else if( output.contains("E: Broken packages") ) {
 		msg = "Your system has broken packages or you are trying to install conflicting packages. See the log for details.";
 	} else if( output.contains("E: Handler silently failed") ) {
-		msg = "Handler silently failed - This can happen if you try to install from the forbidden user/hidden category";
+		msg = "Handler silently failed - This can happen if you try to install from the forbidden user/hidden category. Disabling OVI store repositories might help.";
 	} else if( iTerminated ) {
 		msg = "The operation was cancelled by user";
 	} else if( output.contains("Temporary failure resolving") || output.contains("Could not resolve host") ) {
@@ -804,7 +823,7 @@ void AAptInterface::uiUpdaterAptGetInstall()
 			if( pkg!=0 ) {
 				iAptGetCurrentDownloadFileName = pkg->fileName();
 				iAptGetCurrentFileTotalSize = pkg->size()/1024;
-				pkgname += QString(" (%1 kB)").arg(iAptGetCurrentFileTotalSize);
+				pkgname += QString(" (%L1 kB)").arg(iAptGetCurrentFileTotalSize);
 			}
 			iAptGetDownloadCount++;
 			oper += QString(" %1/%2").arg(iAptGetDownloadCount).arg(iAptGetInstallTotal);
@@ -976,6 +995,7 @@ void AAptInterface::readRepositoryInfo()
 					//qDebug() << r->toListFileNames();
 				} else {
 					delete r;
+					r=0;
 				}
 			}
 		}
@@ -999,8 +1019,10 @@ void AAptInterface::readRepositoryInfo()
 		return;
 	}
 
-	if( ownFound )
+	if( ownFound ) {
+		qDebug() << "own repo lists found";
 		return;
+	}
 
 	QFile ham( KHamRepoListFile );
 	if( ham.open(QIODevice::ReadOnly | QIODevice::Text ) )
@@ -1011,20 +1033,26 @@ void AAptInterface::readRepositoryInfo()
 			Repository* r = new Repository();
 			if( r->setFromString(line) ) {
 				iRepositories.append(r);
+
+#ifdef Q_WS_MAEMO_5
+				// disable the ovi repository by default
+				if( line.contains("https://downloads.maemo.nokia.com/fremantle1.2/ovi/") ) {
+					r->setEnabled(false);
+				}
+#endif
 			} else {
 				delete r;
+				r=0;
 			}
 		}
 		ham.close();
+		qDebug() << "system repo list loaded";
 	}
+
 }
 
 bool AAptInterface::writeRepositories()
 {
-#ifndef Q_WS_MAEMO_5	// for simulator
-	return true;
-#endif
-
 	iNeedListRefresh = true;
 
 	QFile own( KOwnRepoFile );
@@ -1063,10 +1091,6 @@ bool AAptInterface::writeRepositories()
 
 bool AAptInterface::needRepoRefresh()
 {
-#ifndef Q_WS_MAEMO_5	// for simulator
-	return false;
-#endif
-
 	if( iNeedRepoRefresh || iSettings->qsettings()->value("need_repo_refresh", false).toBool() ) {
 		iNeedRepoRefresh = false;
 		iSettings->qsettings()->setValue("need_repo_refresh", false);
@@ -1575,11 +1599,27 @@ void AAptInterface::removeFromBlacklist(Package *pkg, BlacklistSelect::blackList
 		return;
 	}
 
-	QStringList newlist;
+	//QStringList newlist;
 	bool removed = false;
 
 	for( int i=0; i<iBlacklist.count(); i++ )
 	{
+		if( oldstate == BlacklistSelect::BlacklistAll )
+		{
+			if( iBlacklist.at(i) == pkg->name() ) {
+				iBlacklist.removeAt(i);
+				i--;
+				removed = true;
+			}
+		} else if( oldstate == BlacklistSelect::BlacklistThis ) {
+			if( iBlacklist.at(i) == (pkg->name()+" "+pkg->version()) ) {
+				iBlacklist.removeAt(i);
+				i--;
+				removed = true;
+			}
+		}
+
+		/*
 		if( oldstate == BlacklistSelect::BlacklistAll )
 		{
 			if( !(iBlacklist.at(i) == pkg->name()) ) {
@@ -1589,7 +1629,9 @@ void AAptInterface::removeFromBlacklist(Package *pkg, BlacklistSelect::blackList
 			if( !(iBlacklist.at(i) == (pkg->name()+" "+pkg->version())) ) {
 				newlist << iBlacklist.at(i);
 			} else removed = true;
-		}
+		} else {
+			newlist << iBlacklist.at(i);
+		}*/
 	}
 
 	if( removed )
@@ -1597,7 +1639,7 @@ void AAptInterface::removeFromBlacklist(Package *pkg, BlacklistSelect::blackList
 	else
 		qDebug() << "blacklist:" << pkg->name() << "not in saved list";
 
-	iBlacklist = newlist;
+	//iBlacklist = newlist;
 }
 
 
@@ -1647,7 +1689,7 @@ void AAptInterface::startFetchDates()
 		i.next();
 		if( !i.value()->date().isValid() && i.value()->section().startsWith("user/") && !i.value()->isBlacklisted() )
 		{
-			Repository* repo = 0;
+			const Repository* repo = 0;
 			for( int x=0; x<i.value()->repositories().count(); x++ ) {
 				if( i.value()->repositories().at(x) && i.value()->repositories().at(x)->url().startsWith("http://repository.maemo.org") )
 				{
@@ -1684,13 +1726,13 @@ void AAptInterface::startFetchDates()
 		if( !fe.value()->date().isValid() && fe.value()->section().startsWith("user/") && !fe.value()->isBlacklisted() )
 		{
 			QString url;
-			Repository* repo = 0;
+			const Repository* repo = 0;
 			QString fullFilename = "unknown_filename";
 			for( int x=0; x<fe.value()->repositories().count(); x++ ) {
 				if( fe.value()->repositories().at(x) && fe.value()->repositories().at(x)->url().startsWith("http://repository.maemo.org") )
 				{
 					repo = fe.value()->repositories().at(x);
-					if( fe.value()->fullFileNames().count()>x )
+					if( repo && fe.value()->fullFileNames().count()>x )
 						fullFilename = fe.value()->fullFileNames().at(x);
 					break;
 				}
@@ -1711,7 +1753,7 @@ void AAptInterface::startFetchDates()
 						QApplication::processEvents(QEventLoop::WaitForMoreEvents);
 					}
 				} else {
-					while( iDateRequestsWaiting>50 ) {
+					while( iDateRequestsWaiting>5 ) {
 						QApplication::processEvents(QEventLoop::WaitForMoreEvents);
 					}
 				}
@@ -1742,6 +1784,7 @@ void AAptInterface::startFetchDates()
 		updProgress++;
 	}
 	delete nam;
+	nam=0;
 
 	if( iDateRequestsReceived>0 && iNetworkError != QNetworkReply::NoError &&
 		iNetworkError != QNetworkReply::QNetworkReply::ContentAccessDenied && iNetworkError != QNetworkReply::QNetworkReply::ContentNotFoundError )
@@ -1792,10 +1835,10 @@ void AAptInterface::dateFetchNetworkReply(QNetworkReply* reply)
 {
 	iDateRequestsWaiting--;
 	iDateRequestsReceived++;
-	//qDebug() << "reply" << reply->header(QNetworkRequest::LastModifiedHeader).toDateTime();
 	iNetworkError = reply->error();
+	QDateTime dateModified = reply->header(QNetworkRequest::LastModifiedHeader).toDateTime();
 
-	if( reply->error() == QNetworkReply::NoError && reply->header(QNetworkRequest::LastModifiedHeader).toDateTime().isValid() )
+	if( reply->error() == QNetworkReply::NoError && dateModified.isValid() )
 	{
 		QString pkgname = reply->url().fragment();
 		//qDebug() << pkgname;
@@ -1805,7 +1848,7 @@ void AAptInterface::dateFetchNetworkReply(QNetworkReply* reply)
 
 		Package* pkg = iPackagesAvailable.value(pkgname, 0);
 		if( pkg ) {
-			pkg->setDate( reply->header(QNetworkRequest::LastModifiedHeader).toDateTime() );
+			pkg->setDate( dateModified );
 		} else {
 			qDebug() << "warning: unknown packagename in reply:" << pkgname;
 		}
