@@ -51,7 +51,8 @@ PackageSelector::PackageSelector(Package* pkg, AAptInterface* apt, Settings* set
 		ui->pushButton_blacklist->setEnabled(false);
 
 	if( pkg->icon() && !pkg->icon()->isNull() ) {
-		ui->label_appicon->setPixmap( *pkg->icon() );
+		QPixmap aicon( *pkg->icon() );
+		ui->label_appicon->setPixmap( aicon.scaled(48,48) );
 	} else {
 		ui->label_appicon->setPixmap( QPixmap(":/icons/icons/appdefault.png") );
 	}
