@@ -37,8 +37,9 @@ class PackageSelector : public QDialog
 
 public:
 	explicit PackageSelector(Package* pkg, AAptInterface* apt, Settings* set, QWidget *parent);
-    ~PackageSelector();
+	virtual ~PackageSelector();
 
+	/*
 #ifdef Q_WS_MAEMO_5		// workaround for buggy Qt autorotation
 	int exec() {
 		QRect r = dynamic_cast<QWidget*>(this->parent())->rect();
@@ -49,6 +50,7 @@ public:
 		return e;
 	}
 #endif
+	*/
 
 	Package::operation selectedOperation();
 
@@ -56,6 +58,9 @@ protected:
     void changeEvent(QEvent *e);
 
 private:
+	PackageSelector(const PackageSelector& old);
+	PackageSelector operator= (const PackageSelector& old);
+
 	QString getMaemoOrgUrl(Package* pkg);
 	void updateInfo();
 	void queryChangelog();
