@@ -52,7 +52,7 @@ void ListItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opti
 	int statfilter = index.data(UserRoleCurrentStatFilter).toInt();
 	int catfilter = index.data(UserRoleCurrentCatFilter).toInt();
 	QString upg_version = index.data(UserRoleAvailVersion).toString();
-	BlacklistSelect::blackList blacklisted = (BlacklistSelect::blackList) index.data(UserRoleBlacklisted).toInt();
+	BlacklistSelect::blackList blacklisted = static_cast<BlacklistSelect::blackList>( index.data(UserRoleBlacklisted).toInt() );
 
 	painter->save();
 	QRect r = option.rect;
@@ -260,6 +260,7 @@ PackageView::PackageView(QWidget *parent) : QMainWindow(parent), ui(new Ui::Pack
 	iSearchDescLong = false;
 
 	// fine-tune kinetic scrolling parameters
+#ifdef Q_WS_MAEMO_5
 	QAbstractKineticScroller* listscroller = ui->listWidget->property("kineticScroller").value<QAbstractKineticScroller*>();
 	if( listscroller )
 	{
@@ -272,14 +273,15 @@ PackageView::PackageView(QWidget *parent) : QMainWindow(parent), ui(new Ui::Pack
 		// not good because it alse sets horizontal overshoot:
 		//listscroller->setOvershootPolicy( QAbstractKineticScroller::OvershootAlwaysOn );
 	}
+#endif
 }
 
 PackageView::~PackageView()
 {
-	delete iListCoverLabel;
-	delete iKeyFilter;
-	delete iDimmer;
-    delete ui;
+	delete iListCoverLabel; iListCoverLabel=0;
+	delete iKeyFilter; iKeyFilter=0;
+	delete iDimmer; iDimmer=0;
+	delete ui; ui=0;
 }
 
 void PackageView::orientationChanged()
@@ -290,6 +292,10 @@ void PackageView::orientationChanged()
 
 void PackageView::resizeEvent(QResizeEvent* event)
 {
+	if( iDimmer ) {
+		iDimmer->resize( this->size() );
+	}
+
 	iListCoverLabel->setGeometry( ui->listWidget->rect() );
 	QWidget::resizeEvent(event);
 }
@@ -501,7 +507,7 @@ void PackageView::addListItem(Package* pkg_, QString listname_)
 	{
 		p->setData(UserRoleDescShort, pkg_->descShort());
 		p->setData(UserRoleVersion, pkg_->version());
-		p->setData(UserRoleMarked, (int)pkg_->markedOperation());
+		p->setData(UserRoleMarked, static_cast<int>(pkg_->markedOperation()) );
 		p->setData(UserRoleInstalled, pkg_->isInstalled());
 		p->setData(UserRoleUpgradeable, pkg_->isUpgradeable());
 		p->setData(UserRoleAvailVersion, pkg_->upgradeableVersion());
@@ -509,11 +515,11 @@ void PackageView::addListItem(Package* pkg_, QString listname_)
 		p->setData(UserRoleCurrentCatFilter, iSelectedCatFilter);
 
 		if( pkg_->availablePackage() )
-			p->setData(UserRoleBlacklisted, (int)pkg_->availablePackage()->blacklisted());
+			p->setData(UserRoleBlacklisted, static_cast<int>(pkg_->availablePackage()->blacklisted()) );
 		else
-			p->setData(UserRoleBlacklisted, (int)pkg_->blacklisted());
+			p->setData(UserRoleBlacklisted, static_cast<int>(pkg_->blacklisted()) );
 
-		//qDebug()<<pkg_->name();
+		//qDebug() << pkg_->name();
 
 		pkg_->convertIcon();
 		p->setData(Qt::DecorationRole, *pkg_->icon());
@@ -726,6 +732,14 @@ void PackageView::on_btn_CategoryFilter_clicked()
 		iSortNoticeShown = false;
 
 		openWin();
+
+		if( iSelectedCatFilter==CatFilterBlacklisted && iAptInterface->needListOrDateRefresh() )
+		{
+			ConfirmDialog d(false, this);
+			d.setText("Notice","Since you don't have all package lists currently loaded, not all blacklisted "
+					  "packages are necessarily shown");
+			d.exec();
+		}
 	}
 }
 
@@ -757,6 +771,8 @@ void PackageView::on_btn_StatusFilter_clicked()
 		if( oldfilter==Package::PkgStatInstalled && iSelectedStatFilter!=Package::PkgStatInstalled &&
 			iAptInterface->needListOrDateRefresh() )
 		{
+			iMainWindow->openNetworkConnection();
+
 			iMainWindow->setNextOperation(MainWindow::OpOpenPkgView);
 			iMainWindow->busyDialog(true,"Operation in progress","Reading the rest of the package lists");
 
