@@ -56,13 +56,17 @@ private:
 class ListItemDelegate : public QStyledItemDelegate
 {
 public:
-	ListItemDelegate(QObject *parent=0) : QStyledItemDelegate (parent) { }
+	explicit ListItemDelegate(QObject *parent=0) : QStyledItemDelegate(parent) {}
+	virtual ~ListItemDelegate() {}
 
 	void paint (QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const;
 	QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const;
 	void loadIcons();
 
 private:
+	ListItemDelegate(const ListItemDelegate& old);
+	ListItemDelegate operator= (const ListItemDelegate& old);
+
 	QPixmap iDefaultIcon;
 	QPixmap iIconPkgInstall;
 	QPixmap iIconPkgUpgrade;
@@ -81,8 +85,9 @@ public:
 
 	enum sortOrder { SortAlpha, SortDateDesc, SortSizeDesc };
 
-    explicit PackageView(QWidget *parent = 0);
-    ~PackageView();
+	explicit PackageView(QWidget *parent);
+	virtual ~PackageView();
+
 	void openWin();
 	void resizeEvent(QResizeEvent* event);
 	void setAptInterface(AAptInterface* a_) { iAptInterface=a_; }
@@ -96,9 +101,9 @@ public:
 	void setSearchText(QString text);
 	void setSearchOptions(bool pkgname, bool dispname, bool dshort, bool dlong);
 
-#ifdef Q_WS_MAEMO_5		// workaround for buggy Qt autorotation
 	void show() {
 		if( !isVisible() ) {
+			/*
 			QRect r = dynamic_cast<QMainWindow*>(this->parent())->rect();
 			if(r.width() < r.height()) {
 				this->setAttribute(Qt::WA_Maemo5PortraitOrientation);
@@ -110,12 +115,16 @@ public:
 					this->setAttribute( Qt::WA_Maemo5LandscapeOrientation );
 				}
 				this->setAttribute(Qt::WA_Maemo5StackedWindow);
-				this->setWindowFlags(Qt::Window);
+				this->setWindowFlags( Qt::Window );
 			}
+			*/
+#ifdef Q_WS_MAEMO_5
+			this->setAttribute(Qt::WA_Maemo5StackedWindow);
+			this->setWindowFlags( Qt::Window );
+#endif
 		}
 		QMainWindow::show();
 	}
-#endif
 
 	static const int CatFilterAllMarked = 0;
 	static const int CatFilterAllUser = 1;
@@ -132,6 +141,9 @@ protected:
 	void closeEvent(QCloseEvent *event);
 
 private:
+	PackageView(const PackageView& old);
+	PackageView operator= (const PackageView& old);
+
 	bool doFilterCategory(Package* pkg);
 	QString generateSortString(Package* pkg);
 	void addListItem(Package* pkg_, QString listname_);
