@@ -35,14 +35,15 @@ class RepoView : public QMainWindow
 
 public:
     explicit RepoView(QWidget *parent = 0);
-    ~RepoView();
+	virtual ~RepoView();
+
 	void setAptInterface(AAptInterface* a_) { iAptInterface = a_; }
 	void openWin();
 	void closeEvent(QCloseEvent *event);
 
-#ifdef Q_WS_MAEMO_5		// workaround for buggy Qt autorotation
 	void show() {
 		if( !isVisible() ) {
+			/*
 			QRect r = dynamic_cast<QMainWindow*>(this->parent())->rect();
 			if(r.width() < r.height())
 				this->setAttribute(Qt::WA_Maemo5PortraitOrientation);
@@ -52,18 +53,23 @@ public:
 				else
 					this->setAttribute( Qt::WA_Maemo5LandscapeOrientation );
 			}
+			*/
+#ifdef Q_WS_MAEMO_5
 			this->setAttribute(Qt::WA_Maemo5StackedWindow);
-			this->setWindowFlags(Qt::Window);
+			this->setWindowFlags( Qt::Window );
+#endif
 		}
 		QMainWindow::show();
 	}
-#endif
 
 
 protected:
     void changeEvent(QEvent *e);
 
 private:
+	RepoView(const RepoView& old);
+	RepoView operator= (const RepoView& old);
+
     Ui::RepoView *ui;
 	bool iModified;
 
@@ -71,6 +77,7 @@ private:
 	AAptInterface* iAptInterface;
 
 private slots:
+	void on_actionRe_import_HAM_repo_settings_triggered();
 	void on_listWidget_itemClicked(QListWidgetItem* item);
 	void on_btnNew_clicked();
 };
